# DISCASM: Discordant and Unmapped Read De novo Transcriptome Assembly

DISCASM is a component of the [Trinity Cancer Transcriptome Analysis Toolkit (CTAT)](https://github.com/NCIP/Trinity_CTAT/wiki). DISCASM aims to extract reads that map to reference genomes in a discordant fashion and optionally include reads that do not map to the genome at all, and perform a de novo transcriptome assembly of these reads.  DISCASM relies on the output from STAR (as run via [STAR-Fusion](http://star-fusion.github.io)), and supports de novo transcriptome assembly using Trinity or Oases.

## Running DISCASM

To run DISCASM, you must have the following tools installed:

* [STAR](https://github.com/alexdobin/STAR) aligner.
* [Trinity](http://trinityrnaseq.github.io) or [Oases](https://www.ebi.ac.uk/~zerbino/oases/) transcriptome RNA-Seq assembler

and optionally

* [STAR-Fusion](http://star-fusion.github.io)

Run STAR-Fusion to align your RNA-Seq data to a reference genome. If you do not want to use STAR-Fusion, but rather run STAR directly yourself, see the [STAR-Fusion documentation](https://github.com/STAR-Fusion/STAR-Fusion/wiki) for an example STAR command required for generating the required outputs.

The outputs generated by STAR should include two files:

* Aligned.sortedByCoord.out.bam :the read alignments in bam format.
* Chimeric.out.junction :a listing of the discordantly-mapped reads.

Given these two files and your original RNA-Seq reads, you can run DISCASM like so to **assemble discordant and unmapped reads**:

    DISCASM --chimeric_junctions Chimeric.out.junction \
             --aligned_bam Aligned.sortedByCoord.out.bam \
             --left_fq reads_1.fq.gz --right_fq reads_2.fq.gz \
             --denovo_assembler Trinity \
             --out_dir DISCASM_outdir
    
Options for the **--denovo_assembler** parameter include **Trinity**, **Oases**, or **OasesMultiK**.  

>The OasesMultiK option runs Oases at k-mer values of 19, 23, 27, 31, and 35 and then merges the separate assemblies into a single assembly (eg. as done via [JAFFA](http://www.genomemedicine.com/content/7/1/43)).

>To run DISCASM on just the discordant reads, discard the **--aligned_bam** parameter, and only those reads identified in the Chimeric.out.junction file will be assembled.

## Fusion Transcript Discovery using DISCASM Assembled Transcripts

To identify candidate fusion transcripts (such as in cancer), you can use [GMAP-fusion](http://gmap-fusion.github.io).

## User support

Contact us on our google group <https://groups.google.com/forum/#!forum/trinity_ctat_users>
